@@ -2,7 +2,11 @@ from abc import ABC
 from typing import List, Type
 
 import libcst as cst
-from libcst.codemod import ContextAwareTransformer, VisitorBasedCodemodCommand
+from libcst.codemod import (
+    CodemodContext,
+    ContextAwareTransformer,
+    VisitorBasedCodemodCommand,
+)
 
 
 class BaseCodemodCommand(VisitorBasedCodemodCommand, ABC):
@@ -10,6 +14,10 @@ class BaseCodemodCommand(VisitorBasedCodemodCommand, ABC):
 
     transformers: List[Type[ContextAwareTransformer]]
 
+    def __init__(self, transformers, context: CodemodContext) -> None:
+        self.transformers = transformers
+        super().__init__(context)
+
     def transform_module_impl(self, tree: cst.Module) -> cst.Module:
         for transform in self.transformers:
             inst = transform(self.context)
